@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from django.http import HttpResponse
+from django.http import HttpResponse, HttpResponseNotFound, Http404, HttpResponseForbidden
+from django.core.exceptions import PermissionDenied
 import logging
 logger = logging.getLogger("colorbox")
 
@@ -8,12 +9,18 @@ def popup_redirect(view_func):
     def wrapper(request, *args, **kwargs):
         try:
             response = view_func(request, *args, **kwargs)
-        except:
-            logger.exception("exception inn popup")
+        except Http404:
+            return HttpResponseNotFound()
+        except PermissionDenied:
+            return HttpResponseForbidden()    
+        except Exception, msg:
+            logger.exception(u"exception in popup: {0}".format(msg))
             raise
         if response.status_code == 302:
-            script = '<script>$.colorbox.close(); window.location="%s";</script>' % response['Location']
+            script = u'<script>$.colorbox.close(); window.location="%s";</script>' % response['Location']
             return HttpResponse(script)
+        elif response.status_code != 200:
+            return HttpResponse(status_code=response.status_code)
         else:
             return response
     return wrapper
@@ -22,7 +29,7 @@ def popup_close(view_func):
     def wrapper(request, *args, **kwargs):
         response = view_func(request, *args, **kwargs)
         if not response:
-            script = '<script>$.colorbox.close();</script>'
+            script = '<script>$.colorbox.close(); window.location=window.location;</script>'
             response = HttpResponse(script)
         return response
     return wrapper
